@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.6'
+__version__ = '0.2.7'
 
 __all__ = ['ANY_ARGUMENT',
            'ANY_ARGUMENTS',
@@ -343,33 +343,25 @@ class Verifier(FluentTarget):
 
     def __call__(self, *arguments, **keyword_arguments):
         self._ensure_valid_usage_of_any_arguments(arguments)
-        matching_call_entries = self._count_matching_call_entries(arguments, keyword_arguments)
+        count_of_matching_calls = self._count_matching_call_entries(arguments, keyword_arguments)
 
-        if self._matcher is AT_LEAST_ONCE and not AT_LEAST_ONCE.matches(matching_call_entries):
+        if not self._matcher.matches(count_of_matching_calls):
+            expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
 
             method_of_mock = getattr(self.object, self.attribute_name)
-            if isinstance(self.object, Mock) and isinstance(method_of_mock, Mock):
-                method_of_mock.assert_called_with(*arguments, **keyword_arguments)
-            else:
-                expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
+            is_a_mock_method = isinstance(self.object, Mock) and isinstance(method_of_mock, Mock)
+            if not is_a_mock_method and len(_call_entries) == 0:
+                raise VerificationError(expected_call_entry, self._matcher,
+                                        reason='No patched function has been called.')
 
-                if not _call_entries:
-                    raise VerificationError(expected_call_entry, self._matcher,
-                                            reason='No patched function has been called.')
+            found_calls = []
 
-                found_calls = []
+            for call_entry in _call_entries:
+                target = call_entry.target
+                if target.is_equal_to(self.object, self.attribute_name):
+                    found_calls.append(call_entry)
 
-                for call_entry in _call_entries:
-                    target = call_entry.target
-                    if target.is_equal_to(self.object, self.attribute_name):
-                        found_calls.append(call_entry)
-
-                if found_calls:
-                    raise VerificationError(expected_call_entry, self._matcher, found_calls=found_calls)
-
-        if not self._matcher.matches(matching_call_entries):
-            expected_call_entry = FluentCallEntry(self.object, self.attribute_name, arguments, keyword_arguments)
-            raise VerificationError(expected_call_entry, self._matcher)
+            raise VerificationError(expected_call_entry, self._matcher, found_calls=found_calls)
 
 
 def create_mock(*arguments, **keyword_arguments):
